%define major 14
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d
%define x509major 1
%define libx509 %mklibname mbedx509_ %{x509major}
%define cryptomajor 7
%define libcrypto %mklibname mbedcrypto %{cryptomajor}

Name:           mbedtls
# Please stay on LTS branch 2.28.x:
# https://www.trustedfirmware.org/blog/MBed-TLS_1-3/
Version:        2.28.3
Release:        %mkrel 1
Summary:        Light-weight cryptographic and SSL/TLS library
Group:          System/Libraries
License:        ASL 2.0
URL:            https://tls.mbed.org
Source0:        https://github.com/ARMmbed/mbedtls/archive/%{name}-%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  pkgconfig(libpkcs11-helper-1)
BuildRequires:  pkgconfig(zlib)

%description
mbed TLS (formerly known as PolarSSL) is an SSL library written in ANSI C.
mbed TLS makes it easy for developers to include cryptographic and SSL/TLS
capabilities in their (embedded) products with as little hassle as possible.
It is designed to be readable, documented, tested, loosely coupled and
portable.

This package contains mbed TLS programs.

%package -n %{libname}
Summary:        mbed TLS library
Group:          System/Libraries

%description -n	%{libname}
mbed TLS (formerly known as PolarSSL) is an SSL library written in ANSI C.
mbed TLS makes it easy for developers to include cryptographic and SSL/TLS
capabilities in their (embedded) products with as little hassle as possible.
It is designed to be readable, documented, tested, loosely coupled and
portable.

This package contains the library itself.

%package -n %{libx509}
Summary:        mbed TLS X509 library
Group:          System/Libraries

%description -n %{libx509}
mbed TLS (formerly known as PolarSSL) is an SSL library written in ANSI C.
mbed TLS makes it easy for developers to include cryptographic and SSL/TLS
capabilities in their (embedded) products with as little hassle as possible.
It is designed to be readable, documented, tested, loosely coupled and
portable.

This package contains mbed X509 library.

%package -n %{libcrypto}
Summary:        mbed crypto library
Group:          System/Libraries

%description -n %{libcrypto}
mbed TLS (formerly known as PolarSSL) is an SSL library written in ANSI C.
mbed TLS makes it easy for developers to include cryptographic and SSL/TLS
capabilities in their (embedded) products with as little hassle as possible.
It is designed to be readable, documented, tested, loosely coupled and
portable.

This package contains mbed mbedcrypto library.

%package -n %{develname}
Summary:        mbed TLS development files
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libx509} = %{version}-%{release}
Requires:       %{libcrypto} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
mbed TLS (formerly known as PolarSSL) is an SSL library written in ANSI C.
mbed TLS makes it easy for developers to include cryptographic and SSL/TLS
capabilities in their (embedded) products with as little hassle as possible.
It is designed to be readable, documented, tested, loosely coupled and
portable.

This package contains development files.

%prep
%autosetup -p1 -n %{name}-%{name}-%{version}

# Enable MBEDTLS_THREADING_PTHREAD and MBEDTLS_THREADING_C flags
# https://bugs.mageia.org/show_bug.cgi?id=15391#c4
sed -i -e 's|.*\(#define MBEDTLS_THREADING_C\)|\1|' \
    -e 's|.*\(#define MBEDTLS_THREADING_PTHREAD\)|\1|' \
    include/mbedtls/config.h

%build
%cmake \
    -DUSE_SHARED_MBEDTLS_LIBRARY=ON \
    -DUSE_PKCS11_HELPER_LIBRARY=ON \
    -DENABLE_ZLIB_SUPPORT=ON

%cmake_build

%check
%make_build check PYTHON=%{__python}

%install
%cmake_install

# prevent possible file clashes
pushd %{buildroot}%{_bindir}
    for i in *; do mv ${i} %{name}-${i}; done
popd

rm -f %{buildroot}%{_libdir}/*.a

%files
%doc ChangeLog README*
%{_bindir}/%{name}-*

%files -n %{libname}
%license LICENSE
%{_libdir}/lib%{name}.so.%{major}
%{_libdir}/lib%{name}.so.%{version}

%files -n %{libx509}
%{_libdir}/libmbedx509.so.%{x509major}
%{_libdir}/libmbedx509.so.%{version}

%files -n %{libcrypto}
%{_libdir}/libmbedcrypto.so.%{cryptomajor}
%{_libdir}/libmbedcrypto.so.%{version}

%files -n %{develname}
%{_includedir}/%{name}/
%{_includedir}/psa/
%{_libdir}/libmbed*.so


%changelog
* Tue Apr 18 2023 akien <akien> 2.28.3-1.mga9
+ Revision: 1953573
- Version 2.28.3

* Wed Dec 21 2022 akien <akien> 2.28.2-1.mga9
+ Revision: 1925572
- Version 2.28.2

* Mon Oct 31 2022 akien <akien> 2.28.1-1.mga9
+ Revision: 1900732
- Version 2.28.1
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Jan 11 2022 akien <akien> 2.28.0-1.mga9
+ Revision: 1767966
- Version 2.28.0, new LTS branch
- mbedtls major 14, mbedx509 major 1, mbedcrypto major 7

* Tue Jan 11 2022 akien <akien> 2.16.12-1.mga9
+ Revision: 1767903
- Version 2.16.12

* Wed Jul 07 2021 akien <akien> 2.16.11-1.mga9
+ Revision: 1735094
- Version 2.16.11

* Fri Dec 18 2020 akien <akien> 2.16.9-1.mga8
+ Revision: 1660970
- Version 2.16.9

* Thu Sep 17 2020 akien <akien> 2.16.8-1.mga8
+ Revision: 1627531
- Version 2.16.8, fixes CVE-2020-16150 and other security issues

* Wed Jul 08 2020 akien <akien> 2.16.7-1.mga8
+ Revision: 1603040
- Version 2.16.7 (mga#26924)

* Tue Apr 21 2020 akien <akien> 2.16.6-1.mga8
+ Revision: 1570269
- Version 2.16.6

* Thu Mar 05 2020 akien <akien> 2.16.5-1.mga8
+ Revision: 1554055
- Version 2.16.5

* Wed Feb 19 2020 umeabot <umeabot> 2.16.4-2.mga8
+ Revision: 1544557
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 akien <akien> 2.16.4-1.mga8
+ Revision: 1483309
- Version 2.16.4
+ wally <wally>
- build with new cmake macros

* Tue Jul 09 2019 akien <akien> 2.16.2-1.mga8
+ Revision: 1419783
- Version 2.16.2
- Fix conflicts with mga6

* Wed Apr 03 2019 akien <akien> 2.16.1-2.mga7
+ Revision: 1385567
- Disable building docs (shaves off 6 MB). Devs use online docs nowadays.
- Explicitly enable zlib support.
- Remove unnecessary dependency in libs on the mbedtls util binaries

* Wed Apr 03 2019 akien <akien> 2.16.1-1.mga7
+ Revision: 1385560
- Version 2.16.1, new LTS

* Tue Jan 01 2019 luigiwalser <luigiwalser> 2.7.8-1.mga7
+ Revision: 1347836
- 2.7.8 (fixes CVE-2018-19608)

* Fri Oct 12 2018 mrambo3501 <mrambo3501> 2.7.6-1.mga7
+ Revision: 1319842
- version 2.7.6 fixes CVE-2018-049[7-8] (mga#23660)

* Sun Sep 23 2018 umeabot <umeabot> 2.7.3-3.mga7
+ Revision: 1299493
- Mageia 7 Mass Rebuild

* Tue May 08 2018 daviddavid <daviddavid> 2.7.3-2.mga7
+ Revision: 1227704
- add missing requires on devel subpkg

* Tue May 08 2018 kekepower <kekepower> 2.7.3-1.mga7
+ Revision: 1227673
- Update to version 2.7.3
- Fixes CVE-2018-9988 and CVE-2018-9989 (mga#22914)
- Split x509 and crypto into their own package

* Wed Mar 07 2018 kekepower <kekepower> 2.7.0-1.mga7
+ Revision: 1206999
- Update to version 2.7.0
- This fixes CVE-2017-18187, CVE-2018-0487 and CVE-2018-0488 (mga#22653)

* Thu Dec 28 2017 luigiwalser <luigiwalser> 2.6.0-1.mga7
+ Revision: 1186336
- 2.6.0

* Thu Mar 23 2017 luigiwalser <luigiwalser> 2.4.2-1.mga6
+ Revision: 1094596
- 2.4.2 (fixes CVE-2017-2784)

* Sun Jan 22 2017 akien <akien> 2.4.0-1.mga6
+ Revision: 1083018
- Version 2.4.0
- Version 2.2.1, major 10
- Package ASL 2.0 version instead of GPLv2+

* Tue Jul 05 2016 luigiwalser <luigiwalser> 1.3.17-1.mga6
+ Revision: 1039028
- 1.3.17

* Thu Jan 14 2016 luigiwalser <luigiwalser> 1.3.16-1.mga6
+ Revision: 923139
- library major is now 9
- 1.3.16 (mga#17187)

* Tue Jan 12 2016 luigiwalser <luigiwalser> 2.2.1-1.mga6
+ Revision: 922231
- 2.2.1

* Mon Nov 16 2015 oden <oden> 2.2.0-2.mga6
+ Revision: 903639
- the polarssl -> mbedtls switch was simply premature...

* Mon Nov 16 2015 oden <oden> 2.2.0-1.mga6
+ Revision: 903624
- imported package mbedtls


* Mon Nov 16 2015 Oden Eriksson <oe@nux.se> 2.2.0-1
- polarssl was renamed to mbedtls

* Sat Mar 07 2015 wally <wally> 1.3.9-3.mga5
+ Revision: 817960
- build with POLARSSL_THREADING_PTHREAD and POLARSSL_THREADING_C flags enabled (mga#15391)
- add BuildRequires for graphviz

* Wed Feb 04 2015 luigiwalser <luigiwalser> 1.3.9-2.mga5
+ Revision: 813438
- add upstream patch to fix CVE-2015-1182

* Fri Nov 14 2014 luigiwalser <luigiwalser> 1.3.9-1.mga5
+ Revision: 797260
- 1.3.9 (fixes CVE-2014-8627 and CVE-2014-8628)

* Wed Oct 15 2014 umeabot <umeabot> 1.3.8-3.mga5
+ Revision: 739124
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.3.8-2.mga5
+ Revision: 687708
- Mageia 5 Mass Rebuild

* Thu Jul 31 2014 oden <oden> 1.3.8-1.mga5
+ Revision: 658539
- do not package libpolarssl.a
- 1.3.8 (CVE-2014-4911)
- new major (7)
- drop the make_check_fixes patch, fixed upstream

* Sat Feb 08 2014 oden <oden> 1.3.4-1.mga5
+ Revision: 585843
- 1.3.4 (Security: Missing MPI_CHK calls added around unguarded mpi calls (found by TrustInSoft)
- 1.3.3 (Security: Possible remotely-triggered out-of-bounds memory access fixed (found by TrustInSoft))

* Tue Oct 22 2013 umeabot <umeabot> 1.3.1-2.mga4
+ Revision: 546175
- Mageia 4 Mass Rebuild

* Thu Oct 17 2013 oden <oden> 1.3.1-1.mga4
+ Revision: 502136
- 1.3.1

* Tue Oct 15 2013 oden <oden> 1.3.0-1.mga4
+ Revision: 500388
- 1.3.0

* Tue Sep 24 2013 oden <oden> 1.2.8-1.mga4
+ Revision: 484752
- 1.2.8 (fixes CVE-2013-4623)
- 1.2.6 fixed CVE-2013-0169, CVE-2013-1621

* Sat Feb 09 2013 oden <oden> 1.2.5-1.mga3
+ Revision: 397517
- 1.2.5 (fixes CVE-2013-1621)

* Fri Jan 18 2013 oden <oden> 1.2.3-1.mga3
+ Revision: 389394
- imported package polarssl

* Fri Jan 18 2013 Oden Eriksson <oeriksson@mandriva.com> 1.2.3-1
- initial Mageia package
